==> minitube_2.5.2.orig.tar.gz: minitube-2.5.2/locale/en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ChannelAggregator</name>
    <message numerus="yes">
        <location filename="../src/channelaggregator.cpp" line="185"/>
        <source>You have %n new video(s)</source>
        <translation type="unfinished">
            <numerusform>You have one new video</numerusform>
            <numerusform>You have %n new videos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="90"/>
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform>A minute ago</numerusform>
            <numerusform>%n minutes ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="92"/>
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform>An hour ago</numerusform>
            <numerusform>%n hours ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="94"/>
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform>Yesterday</numerusform>
            <numerusform>%n days ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="96"/>
        <source>%n weeks(s) ago</source>
        <translation type="unfinished">
            <numerusform>A week ago</numerusform>
            <numerusform>%n weeks ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="98"/>
        <source>%n month(s) ago</source>
        <translation type="unfinished">
            <numerusform>A month ago</numerusform>
            <numerusform>%n months ago</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <location filename="../src/downloadmanager.cpp" line="165"/>
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform>One Download</numerusform>
            <numerusform>%n Downloads</numerusform>
        </translation>
    </message>
</context>
</TS>

==> minitube_3.1.orig.tar.gz: minitube-3.1/locale/en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ChannelAggregator</name>
    <message numerus="yes">
        <location filename="../src/channelaggregator.cpp" line="185"/>
        <source>You have %n new video(s)</source>
        <translation type="unfinished">
            <numerusform>You have a new video</numerusform>
            <numerusform>You have %n new videos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="90"/>
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform>A minute ago</numerusform>
            <numerusform>%n minutes ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="92"/>
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform>An hour ago</numerusform>
            <numerusform>%n hours ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="94"/>
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform>Yesterday</numerusform>
            <numerusform>%n days ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="96"/>
        <source>%n weeks(s) ago</source>
        <translation type="unfinished">
            <numerusform>A week ago</numerusform>
            <numerusform>%n weeks ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/datautils.cpp" line="98"/>
        <source>%n month(s) ago</source>
        <translation type="unfinished">
            <numerusform>A month ago</numerusform>
            <numerusform>%n months ago</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <location filename="../src/downloadmanager.cpp" line="165"/>
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform>1 Download</numerusform>
            <numerusform>%n Downloads</numerusform>
        </translation>
    </message>
</context>
</TS>
